%define upstream_name SPECTRWM_3_6_0

Name:           spectrwm
Version:        3.6.0
Release:        %mkrel 1
Summary:        Small Dynamic Tiling Window Manager for X11
License:        ISC
Group:          Graphical desktop/Other
URL:            https://github.com/conformal/spectrwm
Source0:	https://github.com/conformal/spectrwm/archive/%{upstream_name}/%{name}-%{version}.tar.gz
Source10:       COPYING

BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libbsd-overlay)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xt)
BuildRequires:  gettext
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xcb-atom)

Recommends:     dmenu
Recommends:     sysstat
Recommends:     xterm
Recommends:     terminus-font

Provides:       scrotwm

%description
Spectrwm is a small dynamic tiling and reparenting window manager for
X11. It tries to stay out of the way so that valuable screen real
estate can be used for much more important stuff. It has sane defaults
and does not require one to learn a language to do any
configuration. It is written by hackers for hackers and it strives to
be small, compact and fast.
It was largely inspired by xmonad and dwm. Both are fine products but
suffer from things like: crazy-unportable-language-syndrome, silly
defaults, asymmetrical window layout, "how hard can it be?" and good
old NIH. Nevertheless dwm was a phenomenal resource and many good
ideas and code was borrowed from it. On the other hand xmonad has
great defaults, key bindings and xinerama support but is crippled by
not being written in C.

Spectrwm is a beautiful pearl! For it too, was created by grinding
irritation. Nothing is a bigger waste of time than moving windows
around until they are the right size-ish or having just about any
relevant key combination being eaten for some task one never
needs. The path of agony is too long to quote and in classical OpenBSD
fashion (put up, or hack up) a brand new window manager was whooped up
to serve no other purpose than to obey its masters.

%prep
%setup -q -n %{name}-%{upstream_name}

%build
%set_build_flags

%make_build -C linux \
	PREFIX=%{_prefix} \
	LIBDIR=%{_libdir} \
	LDLIBS=-ldl

%install
%make_install -C linux \
	PREFIX=%{_prefix} \
	LIBDIR=%{_libdir} \
	DESTDIR=%{buildroot}

#conf file
install -D -m 0644 -p %{name}.conf %{buildroot}%{_sysconfdir}/%{name}.conf

#examples
install -D -m 0655 -p baraction.sh %{buildroot}%{_datadir}/doc/%{name}/examples/baraction.sh
install -D -m 0655 -p initscreen.sh %{buildroot}%{_datadir}/doc/%{name}/examples/initscreen.sh
install -D -m 0655 -p screenshot.sh %{buildroot}%{_datadir}/doc/%{name}/examples/screenshot.sh

# start file
cat > %{buildroot}%{_bindir}/start%{name} << EOF
exec %{_bindir}/%{name}
EOF

chmod 755 %{buildroot}%{_bindir}/start%{name}

# no devel pkg
rm -rf %{buildroot}%{_libdir}/libswmhack.so

#license
install -D -m 0644 -p %{_sourcedir}/COPYING %{buildroot}%{_datadir}/doc/%{name}/COPYING

# Remove spectrwm config from wrong location
rm -f %{buildroot}%{_prefix}/etc/spectrwm.conf

%posttrans
if [ "$1" -eq 1 ]; then
	if [ -e %{_datadir}/xsessions/41SpectrWM.desktop ]; then
		rm -rf %{_datadir}/xsessions/41SpectrWM.desktop
	fi
	if [ -e %{_sysconfdir}/X11/dm/Sessions/41SpectrWM.desktop ]; then
		rm -rf %{_sysconfdir}/X11/dm/Sessions/41SpectrWM.desktop
	fi
fi

%files
%doc %{_datadir}/doc/%{name}
%config(noreplace) %{_sysconfdir}/%{name}.conf
%{_datadir}/xsessions/spectrwm.desktop
%{_bindir}/*
%{_libdir}/libswmhack.so.*
%{_mandir}/man1/%{name}.1*


%changelog
* Mon Dec 02 2024 daviddavid <daviddavid> 3.6.0-1.mga10
+ Revision: 2120672
- new version: 3.6.0

* Thu Nov 02 2023 kekepower <kekepower> 3.5.0-1.mga10
+ Revision: 2003542
- Update to version 3.5.0

* Wed Mar 30 2022 umeabot <umeabot> 3.4.1-2.mga9
+ Revision: 1834732
- Mageia 9 Mass Rebuild

* Tue Mar 02 2021 kekepower <kekepower> 3.4.1-1.mga9
+ Revision: 1696275
- Update to version 3.4.1

* Fri Feb 14 2020 umeabot <umeabot> 3.2.0-2.mga8
+ Revision: 1521871
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Thu Jan 03 2019 daviddavid <daviddavid> 3.2.0-1.mga7
+ Revision: 1348853
- new version: 3.2.0

* Sun Sep 23 2018 umeabot <umeabot> 3.1.0-2.mga7
+ Revision: 1301133
- Mageia 7 Mass Rebuild

* Sat Feb 10 2018 kekepower <kekepower> 3.1.0-1.mga7
+ Revision: 1200108
- Update to versin 3.1.0

* Fri Feb 24 2017 wally <wally> 3.0.2-3.mga6
+ Revision: 1087744
- drop old obsoletes
- drop devel files as there's no -devel pkg

* Fri Feb 24 2017 wally <wally> 3.0.2-2.mga6
+ Revision: 1087743
- remove generated xsessions .desktop file leftovers on update

* Mon Sep 19 2016 eatdirt <eatdirt> 3.0.2-1.mga6
+ Revision: 1054262
- Fixing missing sources
- Upgraded and desktop file added for sddm

* Thu Feb 04 2016 umeabot <umeabot> 2.1.1-7.mga6
+ Revision: 935740
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.1.1-6.mga5
+ Revision: 742378
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.1.1-5.mga5
+ Revision: 689272
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sat Oct 19 2013 umeabot <umeabot> 2.1.1-4.mga5
+ Revision: 522551
- Mageia 4 Mass Rebuild

* Sun Mar 17 2013 lmenut <lmenut> 2.1.1-3.mga3
+ Revision: 403614
- rebuild for new rpm-mageia-setup
  do not own man lang directories (mga #9055)

* Mon Jan 14 2013 umeabot <umeabot> 2.1.1-2.mga3
+ Revision: 382467
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 2.1.1-1.mga3
+ Revision: 324832
- add pkgconfig(xcb-atom) as BR
- add pkgconfig(xft) as BR
- add pkgconfig(xcursor) as BR
- Global transition from scrotwm to spectrwm
- update Source0
- new version 2.1.1
- upstream rename
- upstream rename
- upstream rename

* Sun Dec 02 2012 kamil <kamil> 0.11.0-1.mga3
+ Revision: 324762
- new version 0.11.0

* Mon Jan 16 2012 kamil <kamil> 0.10.0-0.mga2
+ Revision: 197017
- fix build
- new version 0.10.0
- drop patches merged upstream
  o deb-improve-man-page.patch
  o deb-update-italian-man-page.patch
- drop patches no needed according to upstream
  o deb-remove-bash-assumptions.patch
  o deb-remove-openbsd-assumptions.patch
  o deb-try-versioned-dlopen.patch
  o deb-improve-makefile.patch
- rediff and simplicity patch (drop parts unneeded according to upstream)
  o mga-deb-improve-makefile.patch

* Fri Dec 16 2011 obgr_seneca <obgr_seneca> 0.9.34-4.mga2
+ Revision: 182745
- added mga to improve-makefile.patch

* Fri Dec 16 2011 obgr_seneca <obgr_seneca> 0.9.34-3.mga2
+ Revision: 182619
- removed _disable_ld_no_undefined
- fixed patch 103 so underlinking is gone

* Tue Dec 13 2011 kamil <kamil> 0.9.34-2.mga2
+ Revision: 181320
- revert again to %%{_sourcedir} as it is in RPM SPEC policy

* Tue Dec 13 2011 obgr_seneca <obgr_seneca> 0.9.34-1.mga2
+ Revision: 181206
- removed use of sourcedir
+ kamil <kamil>
- replace %%{_datadir}/man with %%{_mandir}
- use %%find_lang --with-man to handle localised man-pages
- add BR gettext for %%find_lang
- make dmenu,sysstat,xterm,terminux-font suggested not required
- use _disable_ld_no_undefined
- don't ship xsession file - it's done automagically by file triggers
- spec adapted and totally rewritten for Mageia
- use patches from Debian
 o scrotwm-0.9.34-deb-improve-makefile.patch
 o scrotwm-0.9.34-deb-improve-man-page.patch
 o scrotwm-0.9.34-deb-remove-bash-assumptions.patch
 o scrotwm-0.9.34-deb-remove-openbsd-assumptions.patch
 o scrotwm-0.9.34-deb-try-versioned-dlopen.patch
 o scrotwm-0.9.34-deb-update-italian-man-page.patch
- imported package scrotwm


* Tue Jun 14 2011 pascal.bleser@opensuse.org
- update to 0.9.30:
  * now shows the window title in the status bar
  * adds border_width for bar and windows
  * applications like xemacs that would endlessly redraw themselves have been
    fixed
  * a feature to iconize applications has been added
  * when moving a transient to another workspace, the parent is moved as well
  * works around transients that lie about their parent window; this fixes a
    ton of little nits that were not obvious
  * a FOCUSPREV quirk has been added to force the application on exit to focus
    on the application that launched them
  * it prevents double red bordering when an app crashes
  * it fixes drag-to-float
* Tue Jan 18 2011 pascal.bleser@opensuse.org
- update to 0.9.28:
  * fixes 2 crashes
  * adds the window title to the status bar option
* Thu Oct 21 2010 pascal.bleser@opensuse.org
- update to 0.9.27:
  * adds EWMH support
  * fixes a bug where keyboard strokes were no longer accepted
- fixed bugs in the xinitrc file
- added scripts
* Thu Sep 16 2010 pascal.bleser@opensuse.org
- update to 0.9.26:
  * a crash where an app creates and deletes a window quicker than the WM could handle was fixed
  * a borderless option was added
  * the bar can now be moved to the bottom
  * rewritten spawning code fixes a problem with gvim writing to a non-existent stderr
* Sat Jul 10 2010 pascal.bleser@opensuse.org
- update to 0.9.25:
  * makes NVIDIA xrandr work
  * new signal handler: SIGHUP now restarts the wm
  * borderless support has been added; floaters remember their locations
  * prior workspace action has been added
  * several bugfixes
* Tue Apr 20 2010 pascal.bleser@opensuse.org
- update to 0.9.23:
  * fixes an order of operation issue where windows were being unmapped before the new ones were mapped; this should result in a significant speed increase on certain machines when switching work spaces; it fixes a few nits and some memory leaks
- changes from 0.9.21:
  * fixes tiny focus problems
  * adds a Russian translation
* Sat Dec 19 2009 pascal.bleser@opensuse.org
- initial package (0.9.20)
